''''
Source : http://sciences-physiques.ac-besancon.fr/2019/05/19/1ere-pc-etudier-le-mouvement-dun-systeme-avec-python/

Etudier la relation approchée entre la variation du vecteur vitesse d’un système modélisé par un point matériel 
entre deux instants voisins et la somme des forces appliquées sur celui-ci

Point de vue qualitatif

Cette relation peut être approchée en  montrant la colinéarité entre le vecteur variation de vitesse 
entre deux instants proches et le vecteur représentant la somme des forces appliquées au système.
'''
import matplotlib.pyplot as plt

#Les fonctions------------------------------------------------------

def calcul_vitesses(abscisses,ordonnees,temps):
    v_x=[]
    v_y=[]
    for n in range(len(abscisses)-1):
        v_x.append((abscisses[n+1]-abscisses[n])/(temps[n+1]-temps[n]))
        v_y.append((ordonnees[n+1]-ordonnees[n])/(temps[n+1]-temps[n]))
    temps=temps[:-1]
    return v_x,v_y,temps

def representation_graphique(abscisses,ordonnees,v_x,v_y):
    plt.figure(figsize=(10,3))
    plt.subplots_adjust(left=0.06, bottom=0.16, right=0.99, top=0.92,
                wspace=0.2, hspace=None)
    #------------------------------
    plt.subplot(1,3,1)
    plt.scatter(abscisses,ordonnees,marker='+')
    plt.title('Vecteur vitesse instantannée')
    plt.xlabel('x en (m)')
    plt.ylabel('Altitude z en (m)')
    plt.xlim(0.8*min(abscisses),1.2*max(abscisses))
    for i in range(0,len(v_x),1):
        V=plt.quiver(abscisses[i], ordonnees[i] ,v_x[i] , v_y[i],
         scale_units='xy',angles='xy', scale=12)
        #plt.quiverkey(V,0.8,0.8,500,label='v') #Choix de l'échelle sous Edupython
        plt.quiverkey(V,0.8,0.8,10,label='v')    #Choix de l'échelle sous Spyder
    #------------------------------
    plt.subplot(1,3,2)
    plt.scatter(abscisses,ordonnees,marker='+')
    plt.title('Variation du vecteur vitesse')
    plt.xlabel('x en (m)')
    plt.ylabel('Altitude z en (m)')
    plt.xlim(0.8*min(abscisses),1.2*max(abscisses))
    for i in range(1,len(v_x),1):
        DV=plt.quiver(abscisses[i],ordonnees[i],v_x[i]-v_x[i-1],v_y[i]-v_y[i-1],
        scale_units='xy',angles='xy', scale=2, color='red')
        #plt.quiverkey(DV,0.8,0.8,100,label='V(n)-V(n-1)', labelcolor='red') #Choix de l'échelle sous Edupython
        plt.quiverkey(DV,0.8,0.8,1.6,label='V(n)-V(n-1)', labelcolor='red')  #Choix de l'échelle sous Spyder
    #-------------------------------
    plt.subplot(1,3,3)
    plt.scatter(abscisses,ordonnees,marker='+')
    plt.title('Somme des forces extérieures')
    plt.xlabel('x en (m)')
    plt.ylabel('Altitude z en (m)')
    plt.xlim(0.8*min(abscisses),1.2*max(abscisses))
    for i in range(1,len(v_x),1):
        F=plt.quiver(abscisses[i],ordonnees[i],0,-0.06*9.8,
        scale_units='xy',angles='xy', scale=1, color='g')
        #plt.quiverkey(F,0.8,0.8,50,label='F', labelcolor='g') #Choix de l'échelle sous Edupython
        plt.quiverkey(F,0.8,0.8,0.9,label='F', labelcolor='g') #Choix de l'échelle sous Spyder
    #-------------------------------
    plt.show()
    
#Le programme principal--------------------------------------------
x=[...,...,...]
z=[...,...,...]
t=[...,...,...]
v_x,v_y,temps_v=calcul_vitesses(x,z,t)
representation_graphique(x,z,v_x,v_y)
