# -*- coding: utf-8 -*-
"""
Taux d'avencement final de la reaction d'un acide faible sur l'eau et concentration finale
en ions oxonium

Equation de reaction : HA + H20 -> A- + H3O+

La concentration de la solution en acide et le pKa du couple acide faible/base faible sont a renseigner.
"""

#Import des bibliothèques
import numpy as np

#Calcul du taux d'avancement final et de la concentration effective finale en ions oxonium
def taux(Ca,pKa): #Solution d'acide faible de concentration Ca
    Ka = 10**(-pKa)
    #Equation du second degre : Coxonium**2 + Ka*Coxonium-Ka*Ca=0
    a = 1
    b = Ka
    c = -Ka*Ca
    delta = b**2-4*a*c
    Coxonium1 = (-b-np.sqrt(delta))/(2*a)
    Coxonium2 = (-b+np.sqrt(delta))/(2*a)
    if Coxonium1<0:
        Coxonium=Coxonium2
    elif Coxonium2<0:
        Coxonium = Coxonium1
    else :
        Coxonium = min(Coxonium1,Coxonium2)
    taux = Coxonium/Ca
    print ("La concentration effective finale des ions oxonium vaut :","%0.3e" % Coxonium,"mol/L \n"
           "et le taux d'avancement final vaut :","%0.3e" % taux," soit ",round(taux*100,3),"%")
    return (Coxonium,taux)


#Partie du programme à completer
Ca = 0.2  #Concentration de la solution en acide faible apporté en mol/L
pKa = 3.8 #pKa du couple acide faible/base faible

taux(Ca,pKa)