# -*- coding: utf-8 -*-
"""
Taux d'avencement final de la reaction d'un acide faible sur l'eau

Equation de reaction : HA + H20 -> A- + H3O+

La concentration de la solution en acide, le volume et le pKa du couple acide faible/base faible
sont a renseigner.
"""

#Import des bibliothèques
import numpy as np

#Calcul des avancements final et maximal
def taux (Ca, pKa, V): #Solution d'acide faible de concentration Ca et de volume V
    Ka = 10**(-pKa)
    xmax = Ca*V # xmax = Ca*V
    #Equation du second degre : (xf/V)**2 + Ka*xf/V-Ka*Ca=0
    a = 1/(V**2)
    b = Ka/V
    c = -Ka*Ca
    delta = b**2-4*a*c
    xf1 = (-b-np.sqrt(delta))/(2*a)
    xf2 = (-b+np.sqrt(delta))/(2*a)
    if xf1<0:
        xf=xf2
    elif xf2<0:
        xf = xf1
    else :
        xf = min(xf1,xf2)
    taux = xf/xmax
    print("L'avancement final vaut ","%0.3e" % xf," mol")
    print("L'avancement maximal vaut","%0.3e" % xmax,"mol")
    print("et le taux d'avancement final vaut ", "%0.3e" % taux," soit ", round(taux*100,3),"%")
    return (xf,xmax,taux)

#Partie du programme a completer
Ca = 0.2  #Concentration de la solution en acide faible apporte en mol/L
pKa = 3.8 #pKa du couple acide faible/base faible
V = 0.010 #Volume de la solution en L

taux (Ca,pKa,V)
