'''
Tracé des positions successives, des vecteurs vitesse et vecteurs accélération d'un système animé d'un mouvement circulaire accéléré

Ce programme permet d'étudier plus précisément le mouvement de rotation de la centrifugeuse de la cité des étoiles en Russie,
dont le bras rotatif à un rayon R = 7m. Ses coordonnées ont été enregistrées toutes les Dt = 200 ms. La norme de la vitesse de la cabine
augmente pendant un demi-tour : v(t) = k.t avec k = 6,26 m.s-2. Puis celle-ci est constante de valeur v0 = 16,6 m.s-1.

Il peut être demandé à l'élève de compléter le pas de temps Dt ainsi que les expressions des coordonnées vx, vy, ax et ay des vecteurs
vitesse et accélération.
'''

#Importation des bibliothèques et modules
import numpy as np
import matplotlib.pylab as plt
import sys

#Initialisation du pointage
table = []
#Initialisation du temps en seconde
temps = []
#Initialisation des abscisses
x = []
#Initialisation des ordonnées
y = []

#Importation des données------------------------------------------------------
data = np.loadtxt("donnees.txt", skiprows=1) #skiprows : saute la 1ère ligne
table = data[:,:]

#Taille du tableau importé
N = len(table)
M = len(table[0])

#Initialisation des vitesses
vx = np.zeros(N-1)       #Vitesse calculée selon l'axe des abscisses, np.zeros(N-1) : renvoie un tableau à 1D de N-1 zéros.
vy = np.zeros(N-1)       #Vitesse calculée selon l'axe des ordonnées

#Initialisation des accélérations
ax = np.zeros(N-1)       #Accélération calculée selon l'axe des abscisses
ay = np.zeros(N-1)       #Accélération calculée selon l'axe des ordonnées


#Vérification de la structure de ce tableau (3 colonnes ont été exportées : temps, x et y)
if M!=3 :
    print("Problème dans la réalisation de votre pointage. Reprenez le travail et exportez uniquement deux courbes (Mouvement_X et Mouvement_Y)")
    sys.exit() #Moyen rapide de quitter un programme en cas d'erreur

#Importation des coordonnées x, y et t
for i in range(0,N):
    #Génération des listes
    temps.append(float(table[i][0]))
    x.append(float(table[i][1]))
    y.append(float(table[i][2]))

#Création d'une fonction permettant de tracer les vecteurs
def trace_vect(x,y,Vectx,Vecty,titre,couleur,position,taille):
    q = plt.quiver(x,y,Vectx,Vecty,color = couleur,width=0.004)
    plt.quiverkey(q,X=0.5,Y=position,U=taille,label=titre,color=couleur)

'''********************Partie du programme à modifier********************'''
#Initialisation des constantes du problème
Dt = ...      #Pas de temps en s

#Calcul des coordonnées du vecteur vitesse
for i in range(0,N-1):
    vx[i] = ...
    vy[i] = ...

#Calcul des coordonnées du vecteur accélération
for i in range(0,N-2):
    ax[i+1] = ...
    ay[i+1] = ...

'''***************Fin de la partir du programme à modifier***************'''

#Imposer la taille de la zone de travail
plt.figure(1,figsize=(6,6))

#Tracer les vecteurs vitesses calculées
trace_vect(x,y,vx,vy,"Vecteur vitesse",'g',0.4,15)
#Tracer les vecteurs accélérations calculées
trace_vect(x,y,ax,ay,"Vecteur accélération",'r',0.3,30)

#Tracer les positions
plt.plot(x,y,"k.",label="Positions de la cabine")

#Tracer le centre de rotation
plt.plot(0,0,"bo")

#Tracer les rayons
for i in range(0,N):
    plt.plot([0,x[i]],[0,y[i]],'k--',lw=0.2)

#Position du bloc légende
plt.legend(loc='upper right')

#Etiquettes des axes
plt.xlabel(r'$ x $'+'(m)')
plt.ylabel(r'$ y $'+'(m)')

#Titre du graphique
plt.title('Positions, vitesse et accélération de la cabine')
plt.show()
